@@ -2,6 +2,7 @@
 
 import logging
 from collections.abc import Mapping
+from typing import Any, TypeVar
 
 from openai import AsyncOpenAI
 from pydantic import ValidationError
@@ -10,24 +11,28 @@ from semantic_kernel.connectors.ai.open_ai.services.open_ai_config_base import O
 from semantic_kernel.connectors.ai.open_ai.services.open_ai_handler import OpenAIModelTypes
 from semantic_kernel.connectors.ai.open_ai.services.open_ai_text_embedding_base import OpenAITextEmbeddingBase
 from semantic_kernel.connectors.ai.open_ai.settings.open_ai_settings import OpenAISettings
-from semantic_kernel.utils.experimental_decorator import experimental_class
+from semantic_kernel.exceptions.service_exceptions import ServiceInitializationError
+from semantic_kernel.utils.feature_stage_decorator import experimental
 
 logger: logging.Logger = logging.getLogger(__name__)
 
+T_ = TypeVar("T_", bound="OpenAITextEmbedding")
 
-@experimental_class
+
+@experimental
 class OpenAITextEmbedding(OpenAIConfigBase, OpenAITextEmbeddingBase):
     """OpenAI Text Embedding class."""
 
     def __init__(
         self,
-        ai_model_id: str,
+        ai_model_id: str | None = None,
         api_key: str | None = None,
         org_id: str | None = None,
         service_id: str | None = None,
         default_headers: Mapping[str, str] | None = None,
         async_client: AsyncOpenAI | None = None,
         env_file_path: str | None = None,
+        env_file_encoding: str | None = None,
     ) -> None:
         """Initializes a new instance of the OpenAITextCompletion class.
 
@@ -44,42 +49,42 @@ class OpenAITextEmbedding(OpenAIConfigBase, OpenAITextEmbeddingBase):
             async_client (Optional[AsyncOpenAI]): An existing client to use. (Optional)
             env_file_path (str | None): Use the environment settings file as
                 a fallback to environment variables. (Optional)
+            env_file_encoding (str | None): The encoding of the environment settings file. (Optional)
         """
         try:
-            openai_settings = OpenAISettings.create(env_file_path=env_file_path)
-        except ValidationError as e:
-            logger.warning(f"Failed to load OpenAI pydantic settings: {e}")
-
-        api_key = api_key or (
-            openai_settings.api_key.get_secret_value() if openai_settings and openai_settings.api_key else None
-        )
-        org_id = org_id or (openai_settings.org_id if openai_settings and openai_settings.org_id else None)
-        ai_model_id = ai_model_id or (
-            openai_settings.embedding_model_id if openai_settings and openai_settings.embedding_model_id else None
-        )
-
+            openai_settings = OpenAISettings.create(
+                api_key=api_key,
+                org_id=org_id,
+                embedding_model_id=ai_model_id,
+                env_file_path=env_file_path,
+                env_file_encoding=env_file_encoding,
+            )
+        except ValidationError as ex:
+            raise ServiceInitializationError("Failed to create OpenAI settings.", ex) from ex
+        if not openai_settings.embedding_model_id:
+            raise ServiceInitializationError("The OpenAI embedding model ID is required.")
         super().__init__(
-            ai_model_id=ai_model_id,
-            api_key=api_key,
+            ai_model_id=openai_settings.embedding_model_id,
+            api_key=openai_settings.api_key.get_secret_value() if openai_settings.api_key else None,
             ai_model_type=OpenAIModelTypes.EMBEDDING,
-            org_id=org_id,
+            org_id=openai_settings.org_id,
             service_id=service_id,
             default_headers=default_headers,
-            async_client=async_client,
+            client=async_client,
         )
 
     @classmethod
-    def from_dict(cls, settings: dict[str, str]) -> "OpenAITextEmbedding":
+    def from_dict(cls: type[T_], settings: dict[str, Any]) -> T_:
         """Initialize an Open AI service from a dictionary of settings.
 
         Args:
             settings: A dictionary of settings for the service.
         """
-        return OpenAITextEmbedding(
-            ai_model_id=settings["ai_model_id"],
-            api_key=settings.get("api_key", None),
-            org_id=settings.get("org_id", None),
+        return cls(
+            ai_model_id=settings.get("ai_model_id"),
+            api_key=settings.get("api_key"),
+            org_id=settings.get("org_id"),
             service_id=settings.get("service_id"),
-            default_headers=settings.get("default_headers"),
-            env_file_path=settings.get("env_file_path", None),
+            default_headers=settings.get("default_headers", {}),
+            env_file_path=settings.get("env_file_path"),
         )
