@@ -1,11 +1,17 @@
 # Copyright (c) Microsoft. All rights reserved.
 
-from typing import Any
+import logging
+from typing import Annotated, Any, TypeVar
 
-from pydantic import Field
+from pydantic import Field, model_validator
 
+from semantic_kernel.connectors.ai.function_choice_behavior import FunctionChoiceBehavior
 from semantic_kernel.kernel_pydantic import KernelBaseModel
 
+logger = logging.getLogger(__name__)
+
+_T = TypeVar("_T", bound="PromptExecutionSettings")
+
 
 class PromptExecutionSettings(KernelBaseModel):
     """Base class for prompt execution settings.
@@ -18,6 +24,7 @@ class PromptExecutionSettings(KernelBaseModel):
     Attributes:
         service_id (str | None): The service ID to use for the request.
         extension_data (Dict[str, Any]): Any additional data to send with the request.
+        function_choice_behavior (FunctionChoiceBehavior | None): The function choice behavior settings.
 
     Methods:
         prepare_settings_dict: Prepares the settings as a dictionary for sending to the AI service.
@@ -25,8 +32,22 @@ class PromptExecutionSettings(KernelBaseModel):
         from_prompt_execution_settings: Create a prompt execution settings from another prompt execution settings.
     """
 
-    service_id: str | None = Field(None, min_length=1)
+    service_id: Annotated[str | None, Field(min_length=1)] = None
     extension_data: dict[str, Any] = Field(default_factory=dict)
+    function_choice_behavior: Annotated[FunctionChoiceBehavior | None, Field(exclude=True)] = None
+
+    @model_validator(mode="before")
+    @classmethod
+    def parse_function_choice_behavior(cls: type[_T], data: Any) -> dict[str, Any]:
+        """Parse the function choice behavior data."""
+        if isinstance(data, dict):
+            function_choice_behavior_data = data.get("function_choice_behavior")
+            if function_choice_behavior_data:
+                if isinstance(function_choice_behavior_data, str):
+                    data["function_choice_behavior"] = FunctionChoiceBehavior.from_string(function_choice_behavior_data)
+                elif isinstance(function_choice_behavior_data, dict):
+                    data["function_choice_behavior"] = FunctionChoiceBehavior.from_dict(function_choice_behavior_data)
+        return data
 
     def __init__(self, service_id: str | None = None, **kwargs: Any):
         """Initialize the prompt execution settings.
@@ -37,8 +58,11 @@ class PromptExecutionSettings(KernelBaseModel):
                 these are attempted to parse into the keys of the specific prompt execution settings.
         """
         extension_data = kwargs.pop("extension_data", {})
+        function_choice_behavior = kwargs.pop("function_choice_behavior", None)
         extension_data.update(kwargs)
-        super().__init__(service_id=service_id, extension_data=extension_data)
+        super().__init__(
+            service_id=service_id, extension_data=extension_data, function_choice_behavior=function_choice_behavior
+        )
         self.unpack_extension_data()
 
     @property
@@ -56,12 +80,13 @@ class PromptExecutionSettings(KernelBaseModel):
             exclude={
                 "service_id",
                 "extension_data",
+                "structured_json_response",
             },
             exclude_none=True,
             by_alias=True,
         )
 
-    def update_from_prompt_execution_settings(self, config: "PromptExecutionSettings") -> None:
+    def update_from_prompt_execution_settings(self, config: _T) -> None:
         """Update the prompt execution settings from a completion config."""
         if config.service_id is not None:
             self.service_id = config.service_id
@@ -70,12 +95,13 @@ class PromptExecutionSettings(KernelBaseModel):
         self.unpack_extension_data()
 
     @classmethod
-    def from_prompt_execution_settings(cls, config: "PromptExecutionSettings") -> "PromptExecutionSettings":
+    def from_prompt_execution_settings(cls: type[_T], config: _T) -> _T:
         """Create a prompt execution settings from a completion config."""
         config.pack_extension_data()
         return cls(
             service_id=config.service_id,
             extension_data=config.extension_data,
+            function_choice_behavior=config.function_choice_behavior,
         )
 
     def unpack_extension_data(self) -> None:
