@@ -2,24 +2,18 @@
 
 import asyncio
 import logging
-import sys
 
 import aiohttp
 from numpy import ndarray
 from pydantic import ValidationError
 
-if sys.version_info >= (3, 12):
-    pass
-else:
-    pass
-
 from semantic_kernel.connectors.memory.astradb.astra_client import AstraClient
 from semantic_kernel.connectors.memory.astradb.astradb_settings import AstraDBSettings
 from semantic_kernel.connectors.memory.astradb.utils import build_payload, parse_payload
 from semantic_kernel.exceptions import MemoryConnectorInitializationError
 from semantic_kernel.memory.memory_record import MemoryRecord
 from semantic_kernel.memory.memory_store_base import MemoryStoreBase
-from semantic_kernel.utils.experimental_decorator import experimental_class
+from semantic_kernel.utils.feature_stage_decorator import experimental
 
 MAX_DIMENSIONALITY = 20000
 MAX_UPSERT_BATCH_SIZE = 100
@@ -31,7 +25,7 @@ MAX_DELETE_BATCH_SIZE = 1000
 logger: logging.Logger = logging.getLogger(__name__)
 
 
-@experimental_class
+@experimental
 class AstraDBMemoryStore(MemoryStoreBase):
     """A memory store that uses Astra database as the backend."""
 
@@ -45,6 +39,7 @@ class AstraDBMemoryStore(MemoryStoreBase):
         similarity: str,
         session: aiohttp.ClientSession | None = None,
         env_file_path: str | None = None,
+        env_file_encoding: str | None = None,
     ) -> None:
         """Initializes a new instance of the AstraDBMemoryStore class.
 
@@ -58,32 +53,19 @@ class AstraDBMemoryStore(MemoryStoreBase):
             session: Optional session parameter
             env_file_path (str | None): Use the environment settings file as a
                 fallback to environment variables. (Optional)
+            env_file_encoding (str | None): The encoding of the environment settings file. (Optional)
         """
-        astradb_settings = None
         try:
-            astradb_settings = AstraDBSettings.create(env_file_path=env_file_path)
-        except ValidationError as e:
-            logger.warning(f"Failed to load AstraDB pydantic settings: {e}")
-
-        # Load the settings and validate
-        astra_application_token = astra_application_token or (
-            astradb_settings.app_token.get_secret_value() if astradb_settings and astradb_settings.app_token else None
-        )
-        if astra_application_token is None:
-            raise ValueError("The astra_application_token cannot be None.")
-        astra_id = astra_id or (astradb_settings.db_id if astradb_settings and astradb_settings.db_id else None)
-        if astra_id is None:
-            raise ValueError("The astra_id cannot be None.")
-        astra_region = astra_region or (
-            astradb_settings.region if astradb_settings and astradb_settings.region else None
-        )
-        if astra_region is None:
-            raise ValueError("The astra_region cannot be None.")
-        keyspace_name = keyspace_name or (
-            astradb_settings.keyspace if astradb_settings and astradb_settings.keyspace else None
-        )
-        if keyspace_name is None:
-            raise ValueError("The keyspace_name cannot be None.")
+            astradb_settings = AstraDBSettings.create(
+                app_token=astra_application_token,
+                db_id=astra_id,
+                region=astra_region,
+                keyspace=keyspace_name,
+                env_file_path=env_file_path,
+                env_file_encoding=env_file_encoding,
+            )
+        except ValidationError as ex:
+            raise MemoryConnectorInitializationError("Failed to create AstraDB settings.", ex) from ex
 
         self._embedding_dim = embedding_dim
         self._similarity = similarity
@@ -91,15 +73,16 @@ class AstraDBMemoryStore(MemoryStoreBase):
 
         if self._embedding_dim > MAX_DIMENSIONALITY:
             raise MemoryConnectorInitializationError(
-                f"Dimensionality of {self._embedding_dim} exceeds "
-                + f"the maximum allowed value of {MAX_DIMENSIONALITY}."
+                f"Dimensionality of {self._embedding_dim} exceeds the maximum allowed value of {MAX_DIMENSIONALITY}."
             )
 
         self._client = AstraClient(
-            astra_id=astra_id,
-            astra_region=astra_region,
-            astra_application_token=astra_application_token,
-            keyspace_name=keyspace_name,
+            astra_id=astradb_settings.db_id,
+            astra_region=astradb_settings.region,
+            astra_application_token=(
+                astradb_settings.app_token.get_secret_value() if astradb_settings.app_token else None
+            ),
+            keyspace_name=astradb_settings.keyspace,
             embedding_dim=embedding_dim,
             similarity_function=similarity,
             session=self._session,
@@ -117,7 +100,7 @@ class AstraDBMemoryStore(MemoryStoreBase):
         self,
         collection_name: str,
         dimension_num: int | None = None,
-        distance_type: str | None = "cosine",
+        distance_type: str | None = "cosine_similarity",
     ) -> None:
         """Creates a new collection in Astra if it does not exist.
 
@@ -186,7 +169,7 @@ class AstraDBMemoryStore(MemoryStoreBase):
         update = {"$set": build_payload(record)}
         status = await self._client.update_document(collection_name, filter, update, True)
 
-        return status["upsertedId"] if "upsertedId" in status else record._id
+        return status.get("upsertedId", record._id)
 
     async def upsert_batch(self, collection_name: str, records: list[MemoryRecord]) -> list[str]:
         """Upsert a batch of memory records into the data store.
