@@ -21,7 +21,7 @@ from semantic_kernel.exceptions import (
 )
 from semantic_kernel.memory.memory_record import MemoryRecord
 from semantic_kernel.memory.memory_store_base import MemoryStoreBase
-from semantic_kernel.utils.experimental_decorator import experimental_class
+from semantic_kernel.utils.feature_stage_decorator import experimental
 
 logger: logging.Logger = logging.getLogger(__name__)
 
@@ -61,18 +61,16 @@ class _USearchCollection:
 
 
 # PyArrow Schema definition for the embeddings data from `MemoryRecord`.
-_embeddings_data_schema = pa.schema(
-    [
-        pa.field("key", pa.string()),
-        pa.field("timestamp", pa.timestamp("us")),
-        pa.field("is_reference", pa.bool_()),
-        pa.field("external_source_name", pa.string()),
-        pa.field("id", pa.string()),
-        pa.field("description", pa.string()),
-        pa.field("text", pa.string()),
-        pa.field("additional_metadata", pa.string()),
-    ]
-)
+_embeddings_data_schema = pa.schema([
+    pa.field("key", pa.string()),
+    pa.field("timestamp", pa.timestamp("us")),
+    pa.field("is_reference", pa.bool_()),
+    pa.field("external_source_name", pa.string()),
+    pa.field("id", pa.string()),
+    pa.field("description", pa.string()),
+    pa.field("text", pa.string()),
+    pa.field("additional_metadata", pa.string()),
+])
 
 
 class _CollectionFileType(Enum):
@@ -108,16 +106,16 @@ def pyarrow_table_to_memoryrecords(table: pa.Table, vectors: ndarray | None = No
     Returns:
         List[MemoryRecord]: List of MemoryRecords constructed from the table.
     """
-    result_memory_records = [
+    return [
         MemoryRecord(**row.to_dict(), embedding=vectors[index] if vectors is not None else None)
         for index, row in table.to_pandas().iterrows()
     ]
 
-    return result_memory_records
 
-
-@experimental_class
+@experimental
 class USearchMemoryStore(MemoryStoreBase):
+    """Memory store for searching embeddings with USearch."""
+
     def __init__(
         self,
         persist_directory: os.PathLike | None = None,
@@ -214,7 +212,7 @@ class USearchMemoryStore(MemoryStoreBase):
 
         self._collections[collection_name] = _USearchCollection.create_default(embeddings_index)
 
-        return None
+        return
 
     def _read_embeddings_table(self, path: os.PathLike) -> tuple[pa.Table, dict[str, int]]:
         """Read embeddings from the provided path and generate an ID to label mapping.
@@ -283,7 +281,7 @@ class USearchMemoryStore(MemoryStoreBase):
         collection = self._collections.pop(collection_name, None)
         if collection:
             collection.embeddings_index.reset()
-        return None
+        return
 
     async def does_collection_exist(self, collection_name: str) -> bool:
         """Check if collection exists."""
@@ -351,9 +349,10 @@ class USearchMemoryStore(MemoryStoreBase):
         )
 
         # Update embeddings_table
-        ucollection.embeddings_data_table = pa.concat_tables(
-            [ucollection.embeddings_data_table, memoryrecords_to_pyarrow_table(records)]
-        )
+        ucollection.embeddings_data_table = pa.concat_tables([
+            ucollection.embeddings_data_table,
+            memoryrecords_to_pyarrow_table(records),
+        ])
 
         # Update embeddings_id_to_label
         for index, record_id in enumerate(all_records_id):
@@ -404,7 +403,7 @@ class USearchMemoryStore(MemoryStoreBase):
         """Remove a single MemoryRecord using its key."""
         collection_name = collection_name.lower()
         await self.remove_batch(collection_name=collection_name, keys=[key])
-        return None
+        return
 
     async def remove_batch(self, collection_name: str, keys: list[str]) -> None:
         """Remove a batch of MemoryRecords using their keys."""
@@ -419,7 +418,7 @@ class USearchMemoryStore(MemoryStoreBase):
         for key in keys:
             del ucollection.embeddings_id_to_label[key]
 
-        return None
+        return
 
     async def get_nearest_match(
         self,
@@ -506,9 +505,6 @@ class USearchMemoryStore(MemoryStoreBase):
             exact=exact,
             log=log,
         )
-
-        # assert isinstance(result, Matches)  # nosec
-
         relevance_score = 1 / (result.distances + 1)
         filtered_labels = result.keys[np.where(relevance_score >= min_relevance_score)[0]]
 
@@ -566,7 +562,7 @@ class USearchMemoryStore(MemoryStoreBase):
                 self._get_collection_path(collection_name, file_type=_CollectionFileType.PARQUET),
             )
 
-        return None
+        return
 
     async def close(self) -> None:
         """Persist collection, clear.
