@@ -2,16 +2,15 @@
 
 import asyncio
 import logging
-from dataclasses import dataclass
+from typing import Final
 
 import numpy as np
 import weaviate
-from pydantic import ValidationError
 
-from semantic_kernel.connectors.memory.weaviate.weaviate_settings import WeaviateSettings
+from semantic_kernel.exceptions.memory_connector_exceptions import MemoryConnectorInitializationError
 from semantic_kernel.memory.memory_record import MemoryRecord
 from semantic_kernel.memory.memory_store_base import MemoryStoreBase
-from semantic_kernel.utils.experimental_decorator import experimental_class
+from semantic_kernel.utils.feature_stage_decorator import experimental
 
 logger: logging.Logger = logging.getLogger(__name__)
 
@@ -65,105 +64,85 @@ SCHEMA = {
 ALL_PROPERTIES = [property["name"] for property in SCHEMA["properties"]]
 
 
-@dataclass
-class WeaviateConfig:
-    use_embed: bool = False
-    url: str = None
-    api_key: str = None
+class FieldMapper:
+    """This maps attribute names between the SK's memory record and weaviate's schema.
 
+    It provides methods for converting between the two naming conventions.
+    """
 
-@experimental_class
-class WeaviateMemoryStore(MemoryStoreBase):
-    class FieldMapper:
-        """This maps attribute names between the SK's memory record and weaviate's schema.
+    SK_TO_WEAVIATE_MAPPING: Final[dict[str, str]] = {
+        "_key": "key",
+        "_timestamp": "timestamp",
+        "_is_reference": "isReference",
+        "_external_source_name": "externalSourceName",
+        "_id": "skId",
+        "_description": "description",
+        "_text": "text",
+        "_additional_metadata": "additionalMetadata",
+        "_embedding": "vector",
+    }
 
-        It provides methods for converting between the two naming conventions.
-        """
+    WEAVIATE_TO_SK_MAPPING: Final[dict[str, str]] = {v: k for k, v in SK_TO_WEAVIATE_MAPPING.items()}
 
-        SK_TO_WEAVIATE_MAPPING = {
-            "_key": "key",
-            "_timestamp": "timestamp",
-            "_is_reference": "isReference",
-            "_external_source_name": "externalSourceName",
-            "_id": "skId",
-            "_description": "description",
-            "_text": "text",
-            "_additional_metadata": "additionalMetadata",
-            "_embedding": "vector",
+    @classmethod
+    def sk_to_weaviate(cls, sk_dict):
+        """Used to convert a MemoryRecord to a dict of attribute-values that can be used by Weaviate."""
+        return {cls.SK_TO_WEAVIATE_MAPPING.get(k, k): v for k, v in sk_dict.items() if k in cls.SK_TO_WEAVIATE_MAPPING}
+
+    @classmethod
+    def weaviate_to_sk(cls, weaviate_dict):
+        """Used to convert a Weaviate object to a dict that can be used to initialize a MemoryRecord."""
+        return {
+            cls.WEAVIATE_TO_SK_MAPPING.get(k, k): v for k, v in weaviate_dict.items() if k in cls.WEAVIATE_TO_SK_MAPPING
         }
 
-        WEAVIATE_TO_SK_MAPPING = {v: k for k, v in SK_TO_WEAVIATE_MAPPING.items()}
+    @classmethod
+    def remove_underscore_prefix(cls, sk_dict):
+        """Used to initialize a MemoryRecord from a SK's dict of private attribute-values."""
+        return {key.lstrip("_"): value for key, value in sk_dict.items()}
 
-        @classmethod
-        def sk_to_weaviate(cls, sk_dict):
-            """Used to convert a MemoryRecord to a dict of attribute-values that can be used by Weaviate."""
-            return {
-                cls.SK_TO_WEAVIATE_MAPPING.get(k, k): v for k, v in sk_dict.items() if k in cls.SK_TO_WEAVIATE_MAPPING
-            }
 
-        @classmethod
-        def weaviate_to_sk(cls, weaviate_dict):
-            """Used to convert a Weaviate object to a dict that can be used to initialize a MemoryRecord."""
-            return {
-                cls.WEAVIATE_TO_SK_MAPPING.get(k, k): v
-                for k, v in weaviate_dict.items()
-                if k in cls.WEAVIATE_TO_SK_MAPPING
-            }
+@experimental
+class WeaviateMemoryStore(MemoryStoreBase):
+    """A memory store that uses Weaviate as the backend."""
 
-        @classmethod
-        def remove_underscore_prefix(cls, sk_dict):
-            """Used to initialize a MemoryRecord from a SK's dict of private attribute-values."""
-            return {key.lstrip("_"): value for key, value in sk_dict.items()}
-
-    def __init__(self, config: WeaviateConfig | None = None, env_file_path: str | None = None):
+    def __init__(
+        self,
+        url: str | None = None,
+        api_key: str | None = None,
+        use_embed: bool = False,
+        env_file_path: str | None = None,
+        env_file_encoding: str | None = None,
+    ):
         """Initializes a new instance of the WeaviateMemoryStore.
 
-        Optional parameters:
-        - env_file_path (str | None): Whether to use the environment settings (.env) file. Defaults to False.
+        Args:
+            url (str): The URL of the Weaviate instance.
+            api_key (str): The API key to use for authentication.
+            use_embed (bool): Whether to use the client embedding options.
+            env_file_path (str): Whether to use the environment settings (.env) file.
+            env_file_encoding (str): The encoding of the environment settings (.env) file. Defaults to 'utf-8'.
         """
-        # Initialize settings from environment variables or defaults defined in WeaviateSettings
-        weaviate_settings = None
-        try:
-            weaviate_settings = WeaviateSettings.create(env_file_path=env_file_path)
-        except ValidationError as e:
-            logger.warning(f"Failed to load WeaviateSettings pydantic settings: {e}")
+        from semantic_kernel.connectors.memory.weaviate.weaviate_settings import WeaviateSettings
 
-        # Override settings with provided config if available
-        if config:
-            self.settings = self.merge_settings(weaviate_settings, config)
-        else:
-            self.settings = weaviate_settings
-
-        self.settings.validate_settings()
-        self.client = self._initialize_client()
-
-    def merge_settings(self, default_settings: WeaviateSettings, config: WeaviateConfig) -> WeaviateSettings:
-        """Merges default settings with configuration provided through WeaviateConfig.
-
-        This function allows for manual overriding of settings from the config parameter.
-        """
-        return WeaviateSettings(
-            url=config.url or (str(default_settings.url) if default_settings and default_settings.url else None),
-            api_key=config.api_key
-            or (default_settings.api_key.get_secret_value() if default_settings and default_settings.api_key else None),
-            use_embed=(
-                config.use_embed
-                if config.use_embed is not None
-                else (default_settings.use_embed if default_settings and default_settings.use_embed else False)
-            ),
+        self.settings = WeaviateSettings.create(
+            url=url,
+            api_key=api_key,
+            use_embed=use_embed,
+            env_file_path=env_file_path,
+            env_file_encoding=env_file_encoding,
         )
-
-    def _initialize_client(self) -> weaviate.Client:
-        """Initializes the Weaviate client based on the combined settings."""
         if self.settings.use_embed:
-            return weaviate.Client(embedded_options=weaviate.EmbeddedOptions())
-
-        if self.settings.api_key:
-            return weaviate.Client(
-                url=self.settings.url, auth_client_secret=weaviate.auth.AuthApiKey(api_key=self.settings.api_key)
+            self.client = weaviate.Client(embedded_options=weaviate.EmbeddedOptions())
+        elif self.settings.api_key and self.settings.url:
+            self.client = weaviate.Client(
+                url=str(self.settings.url),
+                auth_client_secret=weaviate.auth.AuthApiKey(api_key=self.settings.api_key.get_secret_value()),
             )
-
-        return weaviate.Client(url=self.settings.url)
+        elif self.settings.url:
+            self.client = weaviate.Client(url=str(self.settings.url))
+        else:
+            raise MemoryConnectorInitializationError("WeaviateMemoryStore requires a URL or API key, or to use embed.")
 
     async def create_collection(self, collection_name: str) -> None:
         """Creates a new collection in Weaviate."""
@@ -187,7 +166,7 @@ class WeaviateMemoryStore(MemoryStoreBase):
 
     async def upsert(self, collection_name: str, record: MemoryRecord) -> str:
         """Upserts a record into Weaviate."""
-        weaviate_record = self.FieldMapper.sk_to_weaviate(vars(record))
+        weaviate_record = FieldMapper.sk_to_weaviate(vars(record))
 
         vector = weaviate_record.pop("vector", None)
         weaviate_id = weaviate.util.generate_uuid5(weaviate_record, collection_name)
@@ -208,7 +187,7 @@ class WeaviateMemoryStore(MemoryStoreBase):
             results = []
             with self.client.batch as batch:
                 for record in records:
-                    weaviate_record = self.FieldMapper.sk_to_weaviate(vars(record))
+                    weaviate_record = FieldMapper.sk_to_weaviate(vars(record))
                     vector = weaviate_record.pop("vector", None)
                     weaviate_id = weaviate.util.generate_uuid5(weaviate_record, collection_name)
                     batch.add_data_object(
@@ -237,22 +216,16 @@ class WeaviateMemoryStore(MemoryStoreBase):
 
         get_dict = results.get("data", {}).get("Get", {})
 
-        memory_records = [
-            self._convert_weaviate_doc_to_memory_record(doc) for docs in get_dict.values() for doc in docs
-        ]
-
-        return memory_records
+        return [self._convert_weaviate_doc_to_memory_record(doc) for docs in get_dict.values() for doc in docs]
 
     def _build_multi_get_query(self, collection_name: str, keys: list[str], with_embedding: bool):
         queries = []
         for i, key in enumerate(keys):
-            query = self.client.query.get(collection_name, ALL_PROPERTIES).with_where(
-                {
-                    "path": ["key"],
-                    "operator": "Equal",
-                    "valueString": key,
-                }
-            )
+            query = self.client.query.get(collection_name, ALL_PROPERTIES).with_where({
+                "path": ["key"],
+                "operator": "Equal",
+                "valueString": key,
+            })
             if with_embedding:
                 query = query.with_additional("vector")
 
@@ -266,8 +239,8 @@ class WeaviateMemoryStore(MemoryStoreBase):
         weaviate_doc_copy = weaviate_doc.copy()
         vector = weaviate_doc_copy.pop("_additional", {}).get("vector")
         weaviate_doc_copy["vector"] = np.array(vector) if vector else None
-        sk_doc = self.FieldMapper.weaviate_to_sk(weaviate_doc_copy)
-        mem_vals = self.FieldMapper.remove_underscore_prefix(sk_doc)
+        sk_doc = FieldMapper.weaviate_to_sk(weaviate_doc_copy)
+        mem_vals = FieldMapper.remove_underscore_prefix(sk_doc)
         return MemoryRecord(**mem_vals)
 
     async def remove(self, collection_name: str, key: str) -> None:
@@ -276,10 +249,6 @@ class WeaviateMemoryStore(MemoryStoreBase):
 
     async def remove_batch(self, collection_name: str, keys: list[str]) -> None:
         """Removes a batch of records from Weaviate by keys."""
-        # TODO: Use In operator when it's available
-        #       (https://github.com/weaviate/weaviate/issues/2387)
-        #       and handle max delete objects
-        #       (https://weaviate.io/developers/weaviate/api/rest/batch#maximum-number-of-deletes-per-query)
         for key in keys:
             where = {
                 "path": ["key"],
@@ -320,7 +289,7 @@ class WeaviateMemoryStore(MemoryStoreBase):
 
         get_dict = results.get("data", {}).get("Get", {})
 
-        memory_records_and_scores = [
+        return [
             (
                 self._convert_weaviate_doc_to_memory_record(doc),
                 item["_additional"]["certainty"],
@@ -330,8 +299,6 @@ class WeaviateMemoryStore(MemoryStoreBase):
             for doc in [item]
         ]
 
-        return memory_records_and_scores
-
     async def get_nearest_match(
         self,
         collection_name: str,
