@@ -7,13 +7,16 @@ from urllib.parse import urlparse
 import httpx
 from pydantic import Field
 
+from semantic_kernel.connectors.openapi_plugin.operation_selection_predicate_context import (
+    OperationSelectionPredicateContext,
+)
 from semantic_kernel.kernel_pydantic import KernelBaseModel
-from semantic_kernel.utils.experimental_decorator import experimental_class
+from semantic_kernel.utils.feature_stage_decorator import experimental
 
 AuthCallbackType = Callable[..., Awaitable[Any]]
 
 
-@experimental_class
+@experimental
 class OpenAPIFunctionExecutionParameters(KernelBaseModel):
     """OpenAPI function execution parameters."""
 
@@ -24,11 +27,12 @@ class OpenAPIFunctionExecutionParameters(KernelBaseModel):
     user_agent: str | None = None
     enable_dynamic_payload: bool = True
     enable_payload_namespacing: bool = False
-    operations_to_exclude: list[str] = Field(default_factory=list)
+    operations_to_exclude: list[str] = Field(default_factory=list, description="The operationId(s) to exclude")
+    operation_selection_predicate: Callable[[OperationSelectionPredicateContext], bool] | None = None
 
     def model_post_init(self, __context: Any) -> None:
         """Post initialization method for the model."""
-        from semantic_kernel.connectors.telemetry import HTTP_USER_AGENT
+        from semantic_kernel.utils.telemetry.user_agent import HTTP_USER_AGENT
 
         if self.server_url_override:
             parsed_url = urlparse(self.server_url_override)
