@@ -2,6 +2,7 @@
 
 import logging
 from abc import ABC
+from collections.abc import Mapping, Sequence
 from functools import singledispatchmethod
 from typing import TYPE_CHECKING, Any, Literal
 
@@ -17,9 +18,6 @@ from semantic_kernel.prompt_template.prompt_template_base import PromptTemplateB
 from semantic_kernel.prompt_template.prompt_template_config import PromptTemplateConfig
 
 if TYPE_CHECKING:
-    from semantic_kernel.connectors.openai_plugin.openai_function_execution_parameters import (
-        OpenAIFunctionExecutionParameters,
-    )
     from semantic_kernel.connectors.openapi_plugin.openapi_function_execution_parameters import (
         OpenAPIFunctionExecutionParameters,
     )
@@ -31,6 +29,8 @@ logger: logging.Logger = logging.getLogger(__name__)
 
 
 class KernelFunctionExtension(KernelBaseModel, ABC):
+    """Kernel function extension."""
+
     plugins: dict[str, KernelPlugin] = Field(default_factory=dict)
 
     @field_validator("plugins", mode="before")
@@ -61,18 +61,18 @@ class KernelFunctionExtension(KernelBaseModel, ABC):
         See KernelPlugin.from_directory for more details on how the directory is parsed.
 
         Args:
-            plugin (KernelPlugin | Any | dict[str, Any]): The plugin to add.
+            plugin: The plugin to add.
                 This can be a KernelPlugin, in which case it is added straightaway and other parameters are ignored,
                 a custom class that contains methods with the kernel_function decorator
                 or a dictionary of functions with the kernel_function decorator for one or
                 several methods.
-            plugin_name (str | None): The name of the plugin, used if the plugin is not a KernelPlugin,
+            plugin_name: The name of the plugin, used if the plugin is not a KernelPlugin,
                 if the plugin is None and the parent_directory is set,
                 KernelPlugin.from_directory is called with those parameters,
                 see `KernelPlugin.from_directory` for details.
-            parent_directory (str | None): The parent directory path where the plugin directory resides
-            description (str | None): The description of the plugin, used if the plugin is not a KernelPlugin.
-            class_init_arguments (dict[str, dict[str, Any]] | None): The class initialization arguments
+            parent_directory: The parent directory path where the plugin directory resides
+            description: The description of the plugin, used if the plugin is not a KernelPlugin.
+            class_init_arguments: The class initialization arguments
 
         Returns:
             KernelPlugin: The plugin that was added.
@@ -86,6 +86,8 @@ class KernelFunctionExtension(KernelBaseModel, ABC):
             return self.plugins[plugin.name]
         if not plugin_name:
             raise ValueError("plugin_name must be provided if a plugin is not supplied.")
+        if not isinstance(plugin_name, str):
+            raise TypeError("plugin_name must be a string.")
         if plugin:
             self.plugins[plugin_name] = KernelPlugin.from_object(
                 plugin_name=plugin_name, plugin_instance=plugin, description=description
@@ -123,7 +125,7 @@ class KernelFunctionExtension(KernelBaseModel, ABC):
         prompt: str | None = None,
         prompt_template_config: PromptTemplateConfig | None = None,
         prompt_execution_settings: (
-            PromptExecutionSettings | list[PromptExecutionSettings] | dict[str, PromptExecutionSettings] | None
+            PromptExecutionSettings | Sequence[PromptExecutionSettings] | Mapping[str, PromptExecutionSettings] | None
         ) = None,
         template_format: TEMPLATE_FORMAT_TYPES = KERNEL_TEMPLATE_FORMAT_NAME,
         prompt_template: PromptTemplateBase | None = None,
@@ -204,17 +206,19 @@ class KernelFunctionExtension(KernelBaseModel, ABC):
     def add_plugin_from_openapi(
         self,
         plugin_name: str,
-        openapi_document_path: str,
+        openapi_document_path: str | None = None,
+        openapi_parsed_spec: dict[str, Any] | None = None,
         execution_settings: "OpenAPIFunctionExecutionParameters | None" = None,
         description: str | None = None,
     ) -> KernelPlugin:
-        """Add a plugin from the Open AI manifest.
+        """Add a plugin from the OpenAPI manifest.
 
         Args:
-            plugin_name (str): The name of the plugin
-            openapi_document_path (str): The path to the OpenAPI document
-            execution_settings (OpenAPIFunctionExecutionParameters | None): The execution parameters
-            description (str | None): The description of the plugin
+            plugin_name: The name of the plugin
+            openapi_document_path: The path to the OpenAPI document
+            openapi_parsed_spec: The parsed OpenAPI spec
+            execution_settings: The execution parameters
+            description: The description of the plugin
 
         Returns:
             KernelPlugin: The imported plugin
@@ -226,44 +230,12 @@ class KernelFunctionExtension(KernelBaseModel, ABC):
             KernelPlugin.from_openapi(
                 plugin_name=plugin_name,
                 openapi_document_path=openapi_document_path,
+                openapi_parsed_spec=openapi_parsed_spec,
                 execution_settings=execution_settings,
                 description=description,
             )
         )
 
-    async def add_plugin_from_openai(
-        self,
-        plugin_name: str,
-        plugin_url: str | None = None,
-        plugin_str: str | None = None,
-        execution_parameters: "OpenAIFunctionExecutionParameters | None" = None,
-        description: str | None = None,
-    ) -> KernelPlugin:
-        """Add a plugin from an OpenAPI document.
-
-        Args:
-            plugin_name (str): The name of the plugin
-            plugin_url (str | None): The URL of the plugin
-            plugin_str (str | None): The JSON string of the plugin
-            execution_parameters (OpenAIFunctionExecutionParameters | None): The execution parameters
-            description (str | None): The description of the plugin
-
-        Returns:
-            KernelPlugin: The imported plugin
-
-        Raises:
-            PluginInitializationError: if the plugin URL or plugin JSON/YAML is not provided
-        """
-        return self.add_plugin(
-            await KernelPlugin.from_openai(
-                plugin_name=plugin_name,
-                plugin_url=plugin_url,
-                plugin_str=plugin_str,
-                execution_parameters=execution_parameters,
-                description=description,
-            )
-        )
-
     def get_plugin(self, plugin_name: str) -> "KernelPlugin":
         """Get a plugin by name.
 
@@ -388,9 +360,9 @@ class KernelFunctionExtension(KernelBaseModel, ABC):
         """
         if not self.plugins:
             return []
-        included_plugins = filters.get("included_plugins", None)
+        included_plugins = filters.get("included_plugins")
         excluded_plugins = filters.get("excluded_plugins", [])
-        included_functions = filters.get("included_functions", None)
+        included_functions = filters.get("included_functions")
         excluded_functions = filters.get("excluded_functions", [])
         if included_plugins and excluded_plugins:
             raise ValueError("Cannot use both included_plugins and excluded_plugins at the same time.")
