@@ -2,9 +2,9 @@
 
 import logging
 import os
-from collections.abc import AsyncGenerator
+from collections.abc import AsyncGenerator, Mapping, Sequence
 from html import unescape
-from typing import Any
+from typing import TYPE_CHECKING, Any
 
 import yaml
 from pydantic import Field, ValidationError, model_validator
@@ -12,6 +12,7 @@ from pydantic import Field, ValidationError, model_validator
 from semantic_kernel.connectors.ai.chat_completion_client_base import ChatCompletionClientBase
 from semantic_kernel.connectors.ai.prompt_execution_settings import PromptExecutionSettings
 from semantic_kernel.connectors.ai.text_completion_client_base import TextCompletionClientBase
+from semantic_kernel.const import DEFAULT_SERVICE_NAME
 from semantic_kernel.contents.chat_history import ChatHistory
 from semantic_kernel.contents.chat_message_content import ChatMessageContent
 from semantic_kernel.contents.text_content import TextContent
@@ -31,6 +32,9 @@ from semantic_kernel.prompt_template.const import KERNEL_TEMPLATE_FORMAT_NAME, T
 from semantic_kernel.prompt_template.prompt_template_base import PromptTemplateBase
 from semantic_kernel.prompt_template.prompt_template_config import PromptTemplateConfig
 
+if TYPE_CHECKING:
+    from semantic_kernel.services.ai_service_client_base import AIServiceClientBase
+
 logger: logging.Logger = logging.getLogger(__name__)
 
 PROMPT_FILE_NAME = "skprompt.txt"
@@ -59,9 +63,10 @@ class KernelFunctionFromPrompt(KernelFunction):
         template_format: TEMPLATE_FORMAT_TYPES = KERNEL_TEMPLATE_FORMAT_NAME,
         prompt_template: PromptTemplateBase | None = None,
         prompt_template_config: PromptTemplateConfig | None = None,
-        prompt_execution_settings: None | (
-            PromptExecutionSettings | list[PromptExecutionSettings] | dict[str, PromptExecutionSettings]
-        ) = None,
+        prompt_execution_settings: PromptExecutionSettings
+        | Sequence[PromptExecutionSettings]
+        | Mapping[str, PromptExecutionSettings]
+        | None = None,
     ) -> None:
         """Initializes a new instance of the KernelFunctionFromPrompt class.
 
@@ -85,6 +90,16 @@ class KernelFunctionFromPrompt(KernelFunction):
 through prompt_template_config or in the prompt_template."
             )
 
+        if prompt and prompt_template_config and prompt_template_config.template != prompt:
+            logger.warning(
+                f"Prompt ({prompt}) and PromptTemplateConfig ({prompt_template_config.template}) both supplied, "
+                "using the template in PromptTemplateConfig, ignoring prompt."
+            )
+        if template_format and prompt_template_config and prompt_template_config.template_format != template_format:
+            logger.warning(
+                f"Template ({template_format}) and PromptTemplateConfig ({prompt_template_config.template_format}) "
+                "both supplied, using the template format in PromptTemplateConfig, ignoring template."
+            )
         if not prompt_template:
             if not prompt_template_config:
                 # prompt must be there if prompt_template and prompt_template_config is not supplied
@@ -94,7 +109,9 @@ through prompt_template_config or in the prompt_template."
                     template=prompt,
                     template_format=template_format,
                 )
-            prompt_template = TEMPLATE_FORMAT_MAP[template_format](prompt_template_config=prompt_template_config)  # type: ignore
+            prompt_template = TEMPLATE_FORMAT_MAP[prompt_template_config.template_format](
+                prompt_template_config=prompt_template_config
+            )  # type: ignore
 
         try:
             metadata = KernelFunctionMetadata(
@@ -118,27 +135,30 @@ through prompt_template_config or in the prompt_template."
     @classmethod
     def rewrite_execution_settings(
         cls,
-        data: dict[str, Any],
+        data: Any,
     ) -> dict[str, PromptExecutionSettings]:
         """Rewrite execution settings to a dictionary.
 
         If the prompt_execution_settings is not a dictionary, it is converted to a dictionary.
         If it is not supplied, but prompt_template is, the prompt_template's execution settings are used.
         """
-        prompt_execution_settings = data.get("prompt_execution_settings")
-        prompt_template = data.get("prompt_template")
-        if not prompt_execution_settings:
-            if prompt_template:
-                prompt_execution_settings = prompt_template.prompt_template_config.execution_settings
-                data["prompt_execution_settings"] = prompt_execution_settings
+        if isinstance(data, dict):
+            prompt_execution_settings = data.get("prompt_execution_settings")
+            prompt_template = data.get("prompt_template")
             if not prompt_execution_settings:
-                return data
-        if isinstance(prompt_execution_settings, PromptExecutionSettings):
-            data["prompt_execution_settings"] = {
-                prompt_execution_settings.service_id or "default": prompt_execution_settings
-            }
-        if isinstance(prompt_execution_settings, list):
-            data["prompt_execution_settings"] = {s.service_id or "default": s for s in prompt_execution_settings}
+                if prompt_template:
+                    prompt_execution_settings = prompt_template.prompt_template_config.execution_settings
+                    data["prompt_execution_settings"] = prompt_execution_settings
+                if not prompt_execution_settings:
+                    return data
+            if isinstance(prompt_execution_settings, PromptExecutionSettings):
+                data["prompt_execution_settings"] = {
+                    prompt_execution_settings.service_id or DEFAULT_SERVICE_NAME: prompt_execution_settings
+                }
+            if isinstance(prompt_execution_settings, Sequence):
+                data["prompt_execution_settings"] = {
+                    s.service_id or DEFAULT_SERVICE_NAME: s for s in prompt_execution_settings
+                }
         return data
 
     async def _invoke_internal(self, context: FunctionInvocationContext) -> None:
@@ -150,18 +170,11 @@ through prompt_template_config or in the prompt_template."
 
         if isinstance(prompt_render_result.ai_service, ChatCompletionClientBase):
             chat_history = ChatHistory.from_rendered_prompt(prompt_render_result.rendered_prompt)
-
-            # pass the kernel in for auto function calling
-            kwargs: dict[str, Any] = {}
-            if hasattr(prompt_render_result.execution_settings, "function_call_behavior"):
-                kwargs["kernel"] = context.kernel
-                kwargs["arguments"] = context.arguments
-
             try:
                 chat_message_contents = await prompt_render_result.ai_service.get_chat_message_contents(
                     chat_history=chat_history,
                     settings=prompt_render_result.execution_settings,
-                    **kwargs,
+                    **{"kernel": context.kernel, "arguments": context.arguments},
                 )
             except Exception as exc:
                 raise FunctionExecutionException(f"Error occurred while invoking function {self.name}: {exc}") from exc
@@ -170,14 +183,18 @@ through prompt_template_config or in the prompt_template."
                 raise FunctionExecutionException(f"No completions returned while invoking function {self.name}")
 
             context.result = self._create_function_result(
-                completions=chat_message_contents, chat_history=chat_history, arguments=context.arguments
+                completions=chat_message_contents,
+                chat_history=chat_history,
+                arguments=context.arguments,
+                prompt=prompt_render_result.rendered_prompt,
             )
             return
 
         if isinstance(prompt_render_result.ai_service, TextCompletionClientBase):
             try:
                 texts = await prompt_render_result.ai_service.get_text_contents(
-                    unescape(prompt_render_result.rendered_prompt), prompt_render_result.execution_settings
+                    prompt=unescape(prompt_render_result.rendered_prompt),
+                    settings=prompt_render_result.execution_settings,
                 )
             except Exception as exc:
                 raise FunctionExecutionException(f"Error occurred while invoking function {self.name}: {exc}") from exc
@@ -191,21 +208,17 @@ through prompt_template_config or in the prompt_template."
 
     async def _invoke_internal_stream(self, context: FunctionInvocationContext) -> None:
         """Invokes the function stream with the given arguments."""
-        prompt_render_result = await self._render_prompt(context)
+        prompt_render_result = await self._render_prompt(context, is_streaming=True)
+        if prompt_render_result.function_result is not None:
+            context.result = prompt_render_result.function_result
+            return
 
         if isinstance(prompt_render_result.ai_service, ChatCompletionClientBase):
-            # pass the kernel in for auto function calling
-            kwargs: dict[str, Any] = {}
-            if hasattr(prompt_render_result.execution_settings, "function_call_behavior"):
-                kwargs["kernel"] = context.kernel
-                kwargs["arguments"] = context.arguments
-
             chat_history = ChatHistory.from_rendered_prompt(prompt_render_result.rendered_prompt)
-
             value: AsyncGenerator = prompt_render_result.ai_service.get_streaming_chat_message_contents(
                 chat_history=chat_history,
                 settings=prompt_render_result.execution_settings,
-                **kwargs,
+                **{"kernel": context.kernel, "arguments": context.arguments},
             )
         elif isinstance(prompt_render_result.ai_service, TextCompletionClientBase):
             value = prompt_render_result.ai_service.get_streaming_text_contents(
@@ -216,15 +229,20 @@ through prompt_template_config or in the prompt_template."
                 f"Service `{type(prompt_render_result.ai_service)}` is not a valid AI service"
             )
 
-        context.result = FunctionResult(function=self.metadata, value=value)
+        context.result = FunctionResult(
+            function=self.metadata, value=value, rendered_prompt=prompt_render_result.rendered_prompt
+        )
 
-    async def _render_prompt(self, context: FunctionInvocationContext) -> PromptRenderingResult:
+    async def _render_prompt(
+        self, context: FunctionInvocationContext, is_streaming: bool = False
+    ) -> PromptRenderingResult:
         """Render the prompt and apply the prompt rendering filters."""
         self.update_arguments_with_defaults(context.arguments)
-        service, execution_settings = context.kernel.select_ai_service(self, context.arguments)
 
         _rebuild_prompt_render_context()
-        prompt_render_context = PromptRenderContext(function=self, kernel=context.kernel, arguments=context.arguments)
+        prompt_render_context = PromptRenderContext(
+            function=self, kernel=context.kernel, arguments=context.arguments, is_streaming=is_streaming
+        )
 
         stack = context.kernel.construct_call_stack(
             filter_type=FilterTypes.PROMPT_RENDERING,
@@ -234,10 +252,14 @@ through prompt_template_config or in the prompt_template."
 
         if prompt_render_context.rendered_prompt is None:
             raise PromptRenderingException("Prompt rendering failed, no rendered prompt was returned.")
+        selected_service: tuple["AIServiceClientBase", PromptExecutionSettings] = context.kernel.select_ai_service(
+            function=self, arguments=context.arguments
+        )
         return PromptRenderingResult(
             rendered_prompt=prompt_render_context.rendered_prompt,
-            ai_service=service,
-            execution_settings=execution_settings,
+            ai_service=selected_service[0],
+            execution_settings=selected_service[1],
+            function_result=prompt_render_context.function_result,
         )
 
     async def _inner_render_prompt(self, context: PromptRenderContext) -> None:
@@ -264,6 +286,7 @@ through prompt_template_config or in the prompt_template."
             function=self.metadata,
             value=completions,
             metadata=metadata,
+            rendered_prompt=prompt,
         )
 
     def update_arguments_with_defaults(self, arguments: KernelArguments) -> None:
@@ -315,17 +338,17 @@ through prompt_template_config or in the prompt_template."
         if not config_exists and not prompt_exists:
             raise FunctionInitializationError(
                 f"{PROMPT_FILE_NAME} and {CONFIG_FILE_NAME} files are required to create a "
-                f"function from a directory, path: {str(path)}."
+                f"function from a directory, path: {path!s}."
             )
-        elif not config_exists:
+        if not config_exists:
             raise FunctionInitializationError(
                 f"{CONFIG_FILE_NAME} files are required to create a function from a directory, "
-                f"path: {str(path)}, prompt file is there."
+                f"path: {path!s}, prompt file is there."
             )
-        elif not prompt_exists:
+        if not prompt_exists:
             raise FunctionInitializationError(
                 f"{PROMPT_FILE_NAME} files are required to create a function from a directory, "
-                f"path: {str(path)}, config file is there."
+                f"path: {path!s}, config file is there."
             )
 
         function_name = os.path.basename(path)
