@@ -4,18 +4,19 @@ from typing import Any
 
 from pydantic import PrivateAttr
 
-from semantic_kernel.connectors.ai.embeddings.embedding_generator_base import EmbeddingGeneratorBase
+from semantic_kernel.connectors.ai.embedding_generator_base import EmbeddingGeneratorBase
 from semantic_kernel.memory.memory_query_result import MemoryQueryResult
 from semantic_kernel.memory.memory_record import MemoryRecord
 from semantic_kernel.memory.memory_store_base import MemoryStoreBase
 from semantic_kernel.memory.semantic_text_memory_base import SemanticTextMemoryBase
-from semantic_kernel.utils.experimental_decorator import experimental_class
+from semantic_kernel.utils.feature_stage_decorator import experimental
 
 
-@experimental_class
+@experimental
 class SemanticTextMemory(SemanticTextMemoryBase):
+    """Class for semantic text memory."""
+
     _storage: MemoryStoreBase = PrivateAttr()
-    # TODO: replace with kernel and service_selector pattern
     _embeddings_generator: EmbeddingGeneratorBase = PrivateAttr()
 
     def __init__(self, storage: MemoryStoreBase, embeddings_generator: EmbeddingGeneratorBase) -> None:
@@ -49,7 +50,6 @@ class SemanticTextMemory(SemanticTextMemoryBase):
             additional_metadata (Optional[str]): Additional metadata of the information.
             embeddings_kwargs (Optional[Dict[str, Any]]): The embeddings kwargs of the information.
         """
-        # TODO: not the best place to create collection, but will address this behavior together with .NET SK
         if not await self._storage.does_collection_exist(collection_name=collection):
             await self._storage.create_collection(collection_name=collection)
 
@@ -85,7 +85,6 @@ class SemanticTextMemory(SemanticTextMemoryBase):
             additional_metadata (Optional[str]): Additional metadata of the reference.
             embeddings_kwargs (Optional[Dict[str, Any]]): The embeddings kwargs of the reference.
         """
-        # TODO: not the best place to create collection, but will address this behavior together with .NET SK
         if not await self._storage.does_collection_exist(collection_name=collection):
             await self._storage.create_collection(collection_name=collection)
 
