@@ -8,13 +8,15 @@ from numpy import array, linalg, ndarray
 from semantic_kernel.exceptions import ServiceResourceNotFoundError
 from semantic_kernel.memory.memory_record import MemoryRecord
 from semantic_kernel.memory.memory_store_base import MemoryStoreBase
-from semantic_kernel.utils.experimental_decorator import experimental_class
+from semantic_kernel.utils.feature_stage_decorator import experimental
 
 logger: logging.Logger = logging.getLogger(__name__)
 
 
-@experimental_class
+@experimental
 class VolatileMemoryStore(MemoryStoreBase):
+    """A volatile memory store that stores data in memory."""
+
     _store: dict[str, dict[str, MemoryRecord]]
 
     def __init__(self) -> None:
