@@ -4,6 +4,7 @@ import logging
 from abc import ABC
 
 from pydantic import Field
+from typing_extensions import deprecated
 
 from semantic_kernel.kernel_pydantic import KernelBaseModel
 from semantic_kernel.reliability.pass_through_without_retry import PassThroughWithoutRetry
@@ -13,4 +14,9 @@ logger: logging.Logger = logging.getLogger(__name__)
 
 
 class KernelReliabilityExtension(KernelBaseModel, ABC):
-    retry_mechanism: RetryMechanismBase = Field(default_factory=PassThroughWithoutRetry)
+    """Kernel reliability extension."""
+
+    retry_mechanism: RetryMechanismBase = Field(
+        default_factory=PassThroughWithoutRetry,
+        deprecated=deprecated("retry_mechanism is deprecated; This property doesn't have any effect on the kernel."),
+    )
